@@ -21,6 +21,7 @@ def marshall(params, fields):
         ...         "name": str,
         ...         "nick": str,
         ...         "age": int,
+        ...         "extra": str,
         ...     }
         ... }
 
@@ -30,7 +31,8 @@ def marshall(params, fields):
         >>> params = (
         ...     ("user.name", "Fred Kaputnik"),
         ...     ("user.nick", "fred"),
-        ...     ("user.age", 42))
+        ...     ("user.age", 42),
+        ...     ("user.extra", ""))
 
     Note that the keys of the parameter tuples are dotted paths.
 
@@ -51,15 +53,17 @@ def marshall(params, fields):
         'fred'
         >>> data['user']['age']
         42
+        >>> data['user']['extra']
+        ''
 
     To illustrate error handling, we can violate the validation
     constraint of the ``age`` field.
 
         >>> data, errors = marshall((("user.age", "ten"),), fields)
         
-        >>> data['user']['age'] is None
-        True
-        
+        >>> data['user']['age']
+        'ten'
+
         >>> errors['user']['age'][0]
         "invalid literal for int() with base 10: 'ten'"
 
@@ -158,7 +162,6 @@ def marshall(params, fields):
         try:
             data[path] = value
         except ValueError, error:
-            data[path] = None
             e = errors
             for p in path:
                 e = e[p]
@@ -334,6 +337,7 @@ class Marshaller(object):
         # not comply with the field definition
         data_type = self.traverse(path)
 
+        error = False
         if isinstance(data_type, (tuple, list)):
             if isinstance(value, (tuple, list)):
                 if key in self.data:
@@ -343,7 +347,10 @@ class Marshaller(object):
 
             for v in value:
                 if v is not None and self.coerce and not isinstance(v, data_type[0]):
-                    v = data_type[0](v)
+                    try:
+                        v = data_type[0](v)
+                    except:
+                        error = True
 
                 if isinstance(data_type, list):
                     self.data.setdefault(
@@ -355,12 +362,18 @@ class Marshaller(object):
                         self.data[key] = (v,)
         else:
             if value is not None and self.coerce and not isinstance(value, data_type):
-                value = data_type(value)
+                try:
+                    value = data_type(value)
+                except:
+                    error = True
             self.data[key] = value
 
         if value is not None:
             self.data[None] = True
 
+        if error is True:
+            raise
+
     def __nonzero__(self):
         return self.data.get(None, False)
 
